@@ -1,16 +1,19 @@
 /*
-  Whittaker and Robinson periodogram; Whittaker and Robinson (1924),
-  Legendre & Legendre (1998, 2012, Section 12.4.1).
-  x : a vector of quantitative data
-  T1: first period to analyse
-  T2: last period to analyse (T2 <= n/2)
-  nperm: number of permutations for tests of significance
-  mult : methods for correction for multiple testing; "sidak" or "bonferroni"
-
-  License: GPL-2 
-  Authors:: Pierre Legendre, September 2012; Guillaume Guenard, March 2014,
-  C function
-*/
+ * Whittaker and Robinson periodogram; Whittaker and Robinson (1924),
+ * Legendre & Legendre (1998, 2012, Section 12.4.1).
+ * x : a vector of quantitative data
+ * T1: first period to analyse
+ * T2: last period to analyse (T2 <= n/2)
+ * nperm: number of permutations for tests of significance
+ * mult : methods for correction for multiple testing; "sidak" or "bonferroni"
+ * 
+ * License: GPL-2
+ * Authors: Pierre Legendre, September 2012;
+ *          Guillaume Guenard, March 2014 - September 2024
+ * 
+ * C function
+ * 
+ */
 
 #include"WRperiodogram.h"
 
@@ -66,16 +69,18 @@ void C_WRperiodogram(double* x, int* nx, int* T1, int* T2, double* out, int* npe
   // Allocate memory for the calculation of column means
   double rnb;
   int i, j;
-  double* cmacc = (double*)Calloc(*T2, double);  // Accumulator
-  int* cmden = (int*)Calloc(*T2, int);           // Denominator
+  double* cmacc = (double*)R_Calloc(*T2, double);  // Accumulator
+  int* cmden = (int*)R_Calloc(*T2, int);           // Denominator
   if(cmacc == NULL || cmden == NULL)
     error("Dynamic memory allocation failure in C function BBCMVAR");
   BBCMVAR(x, nx, T1, T2, out, cmacc, cmden);
   if(*nperm > 0)
     {
       double buffer;
-      int idx;
-      double* outperm = (double*)Calloc(*T2 - *T1 + 1, double);
+      int idx, intmod;
+      intmod = INTNUM / (*nx * *T2);  // For the interval to interrupt calculations (proportional to n * *T2).
+      intmod = intmod ? intmod : 1;
+      double* outperm = (double*)R_Calloc(*T2 - *T1 + 1, double);
       if(permout == NULL)
 	error("Dynamic memory allocation failure in C function BBCMVAR");
       // Perform permulation test.
@@ -83,7 +88,8 @@ void C_WRperiodogram(double* x, int* nx, int* T1, int* T2, double* out, int* npe
       // The permutation loop.
       for(i = 0; i < *nperm; i++)
 	{
-	  // I sould add some break point.
+	  if(!(i%intmod))
+	    R_CheckUserInterrupt();
 	  for(j = 0; j < *npidx; j++)
 	    {
 	      do
@@ -104,9 +110,9 @@ void C_WRperiodogram(double* x, int* nx, int* T1, int* T2, double* out, int* npe
 	}
       // End of the permutation loop
       PutRNGstate();
-      Free(outperm);
+      R_Free(outperm);
     }
-  Free(cmden);
-  Free(cmacc);
+  R_Free(cmden);
+  R_Free(cmacc);
   return;
 }
